#==============================================================================
# RNA Configuration File
#==============================================================================
#
#=============================================================================
# Copyright (C) 2003           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#=============================================================================

package RNA::Config;
use strict;
#use lib qw(lib extlib);
use RNA;
use RNA::Hatena;
my $VERSION = $RNA::VERSION;

#------------------------------------------------------------------------------
# 各種設定
#------------------------------------------------------------------------------

# アンテナの更新の方法
#   1: バックグラウンド処理
#        アンテナの更新処理が完了する前にブラウザへのレスポンスを行います．
#        この設定を行うとブラウザからのリクエストと実際の更新の間に時間差が生じます．
#        ※ UNIX系 サーバでのみ設定可能です．
#   0: 通常の処理（アンテナの更新処理が完了するまでブラウザが待たされます）
my $background_update = 1;

#------------------------------------
#  キャッシュディレクトリのトップ
#------------------------------------
my $cache_root = 'cache';

#------------------------------------
# Trackback 追跡について
#------------------------------------
# 	1: 行う,  0:行わない
my $trackback_trace = 1;
# キャッシュディレクトリ
my $trackback_cache_dir = $cache_root . '/trackback';


# Your name
#my $antenna_owner = 'i2k';
my $antenna_owner = "your_name";


#------------------------------------
# 各ページのURL
#------------------------------------

# The base URI (directory) of your RNA. 
#my $base_uri = 'http://www-kasm.nii.ac.jp/~i2k/tmp/rna/';
#my $base_uri = 'http://www.semblog.org/products/rna/';
my $base_uri = 'http://foo.bar.com/rna/';

# トップページ
my $main_index_page  = 'index.html';
my $main_index_uri   = $base_uri . $main_index_page;
my $main_index_title = 'RNA - RSS Semblog Antenna';
my $main_index_description 
	= 'Version '. $VERSION . ' by semblog.org';


# メイン CGI
my $update_cgi_uri = $base_uri . 'rna.cgi';

# 設定用 CGI
my $configure_cgi_uri = $base_uri . 'rna-conf.cgi';

# Pingを受け付ける CGI
my $ping_cgi_uri = $base_uri . 'rna-ping.cgi';

# XML-RPC を受け付ける CGI
my $xmlrpc_cgi_uri = $base_uri . 'rna-xmlrpc.cgi';

# OPML 形式
my $opml_output_uri = $base_uri . 'rna.cgi?mode=opml';

# Cache
my $cache_cgi_uri = $base_uri . 'rna-cache.cgi';


#------------------------------------

# チェック結果（ HTML, RSS ）を格納するディレクトリ
my $view_dir = 'rss';
my $rss_dir  = 'rss';

# RSS用のXMLスタイルシート
my $stylesheet_for_rss = "$view_dir/rss01.xsl";

# 表示用のCSSスタイルシート
my $css_stylesheet = "styles-rna.css";

#------------------------------------
# 走査する RSS のリスト
#------------------------------------
my $site_list = 'site.rdf';
my $site_list_title = 'RNA::Site List';
my $site_list_description = 'RNAでチェックするサイトのリスト';
my $site_list_empty = '-';

#------------------------------------
# サイトのリスト（dc:date順にソート）
#------------------------------------
my $recent_site_rss  = "$rss_dir/recent_site.rdf";
my $recent_site_html = "$view_dir/recent_site.html";
my $recent_site_xml  = "$view_dir/recent_site.xml";
my $recent_site_title       = 'RNA::Updated Sites (サイトのリスト)';
my $recent_site_description = 'サイトを更新時間順に並べています．';

#------------------------------------
# 最新記事のリスト
#------------------------------------
my $num_recent_article = 100;
my $recent_entry_rss  = "$rss_dir/recent_entry.rdf";
my $recent_entry_html = "$view_dir/recent_entry.html";
my $recent_entry_xml  = "$view_dir/recent_entry.xml";
my $recent_entry_title = 'RNA::Recent Entries (最新記事リスト)';
my $recent_entry_description =
	'最新の' . $num_recent_article . '件を表示しています';

#------------------------------------
# サイトごとの記事リスト
#------------------------------------
my $num_per_site = '5';
my $recent_site_entry_rss  = "$rss_dir/recent_site_entry.rdf";
my $recent_site_entry_html = "$view_dir/recent_site_entry.html";
my $recent_site_entry_xml  = "$view_dir/recent_site_entry.xml";
my $recent_site_entry_title = 'RNA::Recent Sites/Entries (サイトごとの最新記事リスト)';
my $recent_site_entry_description =
	'サイトごとに最新記事を'. $num_per_site . '件づつ表示しています．';

# 文字コード
my $encoding = 'UTF-8';

# JavaScript のファイル
my $jscript = "jscript01.js";

# 言語
my $default_language = 'ja';

# はてなアンテナ
my $hatena_flag = $RNA::Hatena::flag;

#------------------------------------
# アンテナのテンプレート
#------------------------------------
my $template_dir = 'template';
my $main_index_template        = $template_dir . '/' . 'main_index_template';
my $recent_site_entry_template = $template_dir . '/' . 'rna_template';
my $recent_site_template       = $template_dir . '/' . 'recent_site_template';
my $recent_entry_template      = $recent_site_template;
my $configure_template         = $template_dir . '/' . 'config_template';
my %template_element = (
	RNAEncoding   => $encoding,
	RNAStyleSheet => $base_uri . $css_stylesheet,
	RNAJavaScript => $base_uri . $jscript,
	RNAUpdateCGIURI => $update_cgi_uri,
	RNATopURI     => $main_index_uri,
	RNAConfigureCGIURI => $configure_cgi_uri,
	RNAPingCGIURI => $ping_cgi_uri,
	RNAXMLRPCCGIURI => $xmlrpc_cgi_uri,
	RNAOPMLOutputURI => $opml_output_uri,
	RNACacheCGIURI => $cache_cgi_uri

);

#------------------------------------------------------------------------------
# 
#------------------------------------------------------------------------------

sub new {
    my $class = shift;
    my $self = {};
    
    bless $self, $class;
    
    $self->init(@_);
    
    return $self;
}

sub init {
    my $self = shift;
    my %hash = @_;

	$self->{Update}->{Background} = $background_update;
	$self->{TrackbackTrace} = $trackback_trace;
	$self->{Cache} = {
		RootDirectory => $cache_root,
		TrackbackDirectory => $trackback_cache_dir
	};

	$self->{Owner}   = $antenna_owner;
	$self->{BaseURI} = $base_uri;

	$self->{MainIndex} = {
		File  => $main_index_page,
		URI   => $main_index_uri,
		Title => $main_index_title,
		Description => $main_index_description
	};

	$self->{UpdateCGIURI}   = $update_cgi_uri;
	$self->{ConfigCGIURI}   = $configure_cgi_uri;
	$self->{PingCGIURI}     = $ping_cgi_uri;
	$self->{XMLRPCCGIURI}   = $xmlrpc_cgi_uri;
	$self->{CacheCGIURI}    = $cache_cgi_uri;

	$self->{ViewDirectory}  = $view_dir;
	$self->{RSSDirectory}       = $rss_dir;
	$self->{XSLTStyleSheet} = $stylesheet_for_rss;
	$self->{CSSStyleSheet}  = $css_stylesheet;

	$self->{SiteList} = {
		URI          => $self->{BaseURI} . $site_list ,
		File         => $site_list,
		Title        => $site_list_title,
		Description  => $site_list_description,
		EmptyContent => $site_list_empty
	};

	$self->{RecentSiteList} = {
		RSS     => $recent_site_rss,
		HTML    => $recent_site_html,
		XML     => $recent_site_xml,
		Title   => $recent_site_title,
		Description => $recent_site_description
	};

	$self->{RecentEntryList} = {
		Number => $num_recent_article,
		RSS    => $recent_entry_rss,
		HTML   => $recent_entry_html,
		XML    => $recent_entry_xml,
		Title  => $recent_entry_title,
		Description => $recent_entry_description
	};

	$self->{RecentSiteEntryList} = {
		NumberPerSite      => $num_per_site,
		RSS                => $recent_site_entry_rss,
		HTML               => $recent_site_entry_html,
		XML                => $recent_site_entry_xml,
		Title              => $recent_site_entry_title,
		Description        => $recent_site_entry_description
	};

	$self->{Encoding} = $encoding;
	$self->{JavaScript} = $jscript;
	$self->{Language} = $default_language;
	$self->{HatenaFlag} = $hatena_flag;
	
	$self->{Template} = {
		Directory            => $template_dir,
		MainIndex            => $main_index_template,
		RecentSiteEntryList  => $recent_site_entry_template,
		RecentSiteList       => $recent_site_template,
		RecentEntryList      => $recent_entry_template,
		Configure            => $configure_template,
		Element => \%template_element
	};
}

# $bool = $self->is_empty_content($str);
sub is_empty_content
{
	my $self = shift;
	my $str = shift;

	my $empty_content = $self->{SiteList}->{EmptyContent};
	
	return ($str eq $empty_content || !$str) ? 1 : 0;
}

# $empty_value = $self->empty_value;
sub empty_value
{
	my $self = shift;
	return $self->{SiteList}->{EmptyContent};
}

#==============================================================================
1;
